#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

using System;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;

using EPiServer;
using EPiServer.Core;
using EPiServer.Filters;
using EPiServer.Web.WebControls;

namespace EPiServer.Templates.Demo.Units.Placeable
{
	/// <summary>
	///	Lists the pages that has been changed in the last x hours, 
    /// where x is the number of hours specified in the property "RecentHours".
	/// </summary>
	public partial class ChangedPages : UserControlBase
	{
        // "RecentContainer" (PropertyPageReference)[Optional, Default value=Start page for site] defines the root page for changed pages.

        // "RecentHours" (PropertyNumber)Required, No default value] Number of hours back in time to check for changed pages.
        private static readonly string _recentHoursPropertyName = "RecentHours";

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            AddChangedRecentlyCriteria();
            RecentSearchDataSource.DataBind();
        }
        
        private void AddChangedRecentlyCriteria()
        {
            PropertyCriteriaControl crit = new PropertyCriteriaControl();
            crit.Name = "PageChanged";
            crit.Value = DateTime.Now.Subtract(TimeSpan.FromHours((int)CurrentPage[_recentHoursPropertyName])).ToString();
            crit.Condition = CompareCondition.GreaterThan;
            crit.Type = PropertyDataType.Date;
            RecentSearchDataSource.Criteria.Add(crit);
        }
	}
}