#region Copyright
/*
Copyright (c) 2008 EPiServer AB.  All rights reserved.

This code is released by EPiServer AB under the Source Code File - Specific License Conditions, published August 20, 2007. 
See http://www.episerver.com/Specific_License_Conditions for details. 
*/
#endregion

#region Known Limitations
/*
The template has the following known limitations:
- Performance limitations
Since the file list control has to retrieve all files added to the the work room to be able to
sort them properly there might be performance issues with many files.

*/
#endregion

using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;

using EPiServer.Core;
using EPiServer.Templates.Demo.Workroom.Core;

namespace EPiServer.Templates.Demo.Workroom.Pages
{
    public partial class Start : WorkroomPageBase
    {
        private static readonly string _fileManagerPageTypeName = "[Demo] Workroom File Manager";

        /// <summary>
        /// Raises the <see cref="E:System.Web.UI.Control.Load"/> event.
        /// </summary>
        /// <param name="e">The <see cref="T:System.EventArgs"/> object that contains the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            if (!IsPostBack)
            {
                FileList.Visible = IsFileManagerVisibleInMenu();
                NewsListUnit.Visible =  !PageReference.IsNullOrEmpty((PageReference)CurrentPage["NewsRoot"]) && 
                                        DataFactory.Instance.GetPage((PageReference)CurrentPage["NewsRoot"]).VisibleInMenu;;
                CalendarList.Visible =  !PageReference.IsNullOrEmpty((PageReference)CurrentPage["CalendarContainer"]) && 
                                        DataFactory.Instance.GetPage((PageReference)CurrentPage["CalendarContainer"]).VisibleInMenu;

                FileList.DataBind();
                NewsListUnit.DataBind();
            }

            CalendarList.DataBind();
        }

        /// <summary>
        /// Determines whether there is any child to the current page that is a file manager with visible in menu set to true.
        /// </summary>
        /// <returns>
        /// 	<c>true</c> if there is a file manager with VisibleInMenu = true; otherwise, <c>false</c>.
        /// </returns>
        private bool IsFileManagerVisibleInMenu()
        {
            bool visibleInMenu = false;
            PageDataCollection children = GetChildren(CurrentPageLink);

            foreach (PageData child in children)
            {
                if (child.PageTypeName == _fileManagerPageTypeName && child.VisibleInMenu)
                {
                    visibleInMenu = true;
                    break;
                }
            }

            return visibleInMenu;
        }
    }
}
